/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_INCLUDE_HTML_QUOTE_H
#define SQUID_INCLUDE_HTML_QUOTE_H

#ifdef __cplusplus
extern "C"
#else
extern
#endif

char *html_quote(const char *);

#endif /* SQUID_INCLUDE_HTML_QUOTE_H */

